# lndb-rest: Single-instance management

This is the REST API for LaminDB!

## Installation

1. Clone this repository
2. Navigate to the repository and run:

   ```
   pip install .
   ```

## Start the server

Start the server by running:

```
./run-local-dev.sh
```

The instance and the user used by the server are defined in run-local-dev.sh file.
Feel free to override them if needed!

## Usage

Access API documentation from this endpoint:

```
http://localhost:8000/docs
```
